#include "includes.h"
#include "stm32f10x.h"

#define   DEF_FALSE 0
#define   DEF_TRUE  1

void GUI_TOUCH_Exec(void);
int GUI_Init(void) ;
void GUIDEMO_main(void);

#define  APP_TASK_START_STK_SIZE             521
#define  APP_TASK_USER_IF_STK_SIZE           521
#define  APP_TASK_KBD_STK_SIZE               521

/* ----------------- APPLICATION GLOBALS ------------------ */
static OS_STK AppTaskStartStk[APP_TASK_START_STK_SIZE];
static OS_STK AppTaskUserIFStk[APP_TASK_USER_IF_STK_SIZE];
static OS_STK AppTaskKbdStk[APP_TASK_KBD_STK_SIZE];

#define  APP_TASK_START_PRIO                   3
#define  APP_TASK_KBD_PRIO                     4
#define  APP_TASK_USER_IF_PRIO                 5
#define  APP_TASK_PROBE_STR_PRIO               6

/*
*********************************************************************************************************
*                                    KEYBOARD RESPONSE TASK
*
* Description : This task monitors the state of the push buttons and passes messages to AppTaskUserIF()
*
* Arguments   : p_arg   is the argument passed to 'AppStartKbd()' by 'OSTaskCreate()'.
*
* Returns     : none
*********************************************************************************************************
*/

static  void  AppTaskKbd (void *p_arg)
{
	u8 tick=0;
	(void)p_arg;
	while(DEF_TRUE) 
	{
		tick++;
		OSTimeDlyHMSM(0,0,0,10); 
		GUI_TOUCH_Exec(); 
		if(tick&0x10)
		{
			GPIO_SetBits(GPIOF,GPIO_Pin_6);
			GPIO_ResetBits(GPIOF,GPIO_Pin_7);
		}
		else
		{
			GPIO_ResetBits(GPIOF,GPIO_Pin_6);
			GPIO_SetBits(GPIOF,GPIO_Pin_7);
		}
	}
}

/*
*********************************************************************************************************
*                                         USER INTERFACE TASK
*
* Description : This task updates the LCD screen based on messages passed to it by AppTaskKbd().
*
* Arguments   : p_arg   is the argument passed to 'AppStartUserIF()' by 'OSTaskCreate()'.
*
* Returns     : none
*********************************************************************************************************
*/

static  void  AppTaskUserIF (void *p_arg)
{ 
	(void)p_arg;
	GUI_Init();
	while(DEF_TRUE) 
	{
		GUIDEMO_main();
	}
}

void Task_Start(void)
{
	INT8U  err;
	
	OSTaskCreateExt( AppTaskUserIF,(void *)0,
				   (OS_STK *)&AppTaskUserIFStk[APP_TASK_USER_IF_STK_SIZE-1],
				   APP_TASK_USER_IF_PRIO,
				   APP_TASK_USER_IF_PRIO,
				   (OS_STK *)&AppTaskUserIFStk[0],
	               APP_TASK_USER_IF_STK_SIZE,
	               (void *)0,
	               OS_TASK_OPT_STK_CHK|OS_TASK_OPT_STK_CLR);
	
	
	#if (OS_TASK_NAME_SIZE > 8)
		OSTaskNameSet(APP_TASK_USER_IF_PRIO, "User I/F", &err);
	#endif
	
	
	OSTaskCreateExt( AppTaskKbd,
				   (void *)0,
				   (OS_STK *)&AppTaskKbdStk[APP_TASK_KBD_STK_SIZE-1],
				   APP_TASK_KBD_PRIO,
				   APP_TASK_KBD_PRIO,
				   (OS_STK *)&AppTaskKbdStk[0],
	               APP_TASK_KBD_STK_SIZE,
	               (void *)0,
	               OS_TASK_OPT_STK_CHK|OS_TASK_OPT_STK_CLR);
	
	#if (OS_TASK_NAME_SIZE > 8)
		OSTaskNameSet(APP_TASK_KBD_PRIO, "Keyboard", &err);
	#endif
}