#include "gui.h"
#include "ssd1963.h"
#include "stm32f10x.h"
#include "ascii_8x16_font.h"



/*******************************************************************************
* Function Name  : LCD_WriteCom
* Description    : Writes to the LCD RAM.
* Input          : - RGB_Code: the pixel color in RGB mode (5-6-5).
* Output         : None
* Return         : None
*******************************************************************************/
void LCD_WriteCom(u16 LCD_Reg)
{
	LCD_RD(1);					/*ʧ*/
	LCD_CS(0);					/*Ƭѡ*/
	LCD_RS(0);					/*0ʾ*/
	DataToWrite(LCD_Reg);
	LCD_WR(0);				
	LCD_WR(1);					/*д*/
	LCD_CS(1);		  
}

/*******************************************************************************
* Function Name  : LCD_WriteRAM
* Description    : Writes to the LCD RAM.
* Input          : - RGB_Code: the pixel color in RGB mode (5-6-5).
* Output         : None
* Return         : None
*******************************************************************************/
void LCD_WriteRAM(u16 RGB_Code)					 
{
	LCD_RD(1);					/*ʧ*/
	LCD_CS(0);
	LCD_RS(1);					/*1ʾ*/
	DataToWrite(RGB_Code);
	LCD_WR(0);
	LCD_WR(1);					/*д*/
	LCD_CS(1);	
}

/*******************************************************************************
* Function Name  : LCD_ReadRAM
* Description    : Reads the LCD RAM.
* Input          : None
* Output         : None
* Return         : LCD RAM Value.
*******************************************************************************/
u16 LCD_ReadRAM(void)
{
	uint16_t temp;
	
	LCD_RD(1);					/*ʧ*/
	LCD_CS(0);					/*Ƭѡ*/
	LCD_RS(0);					/*0ʾ*/
	DataToWrite(0x002e);
	LCD_WR(0);				
	LCD_WR(1);					/*д*/
	
	/* Ϊģʽ */
	GPIOC->CRL=0x88888888;
	GPIOB->CRH=0x88888888;
	LCD_RS(1);					/*1ʾ*/
	__nop();__nop();
	__nop();__nop();
	LCD_RD(0);
	__nop();__nop();
	__nop();__nop();
	LCD_RD(1);					/*ض*/
	__nop();__nop();
	__nop();__nop();
	temp=DataToRead();
	__nop();__nop();
	__nop();__nop();
	LCD_CS(1);
	/* Ϊģʽ */
	GPIOC->CRL=0x33333333;
	GPIOB->CRH=0x33333333;
	
	
	return temp;				    	 	
}

void ssd1963_SetCursor(u16 x,u16 y)
{				
    LCD_WriteCom(0x002A);	
	LCD_WriteRAM(x>>8);	    
	LCD_WriteRAM(x&0x00ff);
	LCD_WriteRAM(HDP>>8);	    
	LCD_WriteRAM(HDP&0x00ff);
    LCD_WriteCom(0x002b);	
	LCD_WriteRAM(y>>8);	    
	LCD_WriteRAM(y&0x00ff);
	LCD_WriteRAM(VDP>>8);	    
	LCD_WriteRAM(VDP&0x00ff);
}


/*******************************************************************************
* Function Name  : LCD_CtrlLinesConfig
* Description    : Configures LCD Control lines (FSMC Pins) in alternate function
                   Push-Pull mode.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void LCD_CtrlLinesConfig(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB | RCC_APB2Periph_GPIOC,ENABLE);

	/* GPIOB *********************/	
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_8 | GPIO_Pin_9 | GPIO_Pin_10 | GPIO_Pin_11 
								| GPIO_Pin_12 | GPIO_Pin_13 | GPIO_Pin_14 | GPIO_Pin_15;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;   // ʽ
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;  // IOΪ50MHZ
  	GPIO_Init(GPIOB, &GPIO_InitStructure);
	
	/* ÿGPIOC  *********************/	
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 
								| GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7 
								| GPIO_Pin_8 | GPIO_Pin_9 | GPIO_Pin_10 | GPIO_Pin_11;
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;   // ʽ
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;  // IOΪ50MHZ
  	GPIO_Init(GPIOC, &GPIO_InitStructure);
}

void Delay_10ms(u32 Time)
{
  	u32 Daly_Time = 0;
	Time *= 5;
	do
	{
		Daly_Time ++;
		Daly_Time --;
		Daly_Time ++;
		__nop();__nop();
	}
	while(Daly_Time < Time);
}
/****************************************************************************
*     ƣvoid ssd1963_init()
*     ܣʼ ssd1963_init 
* ڲ
* ڲ
* ˵    
* ÷ili9320_Initializtion();
****************************************************************************/
void ssd1963_init(void)
{
	/* LCD˿ */
	LCD_CtrlLinesConfig();

#define LCD_WR_REG	 LCD_WriteCom
#define LCD_WR_DATA	 LCD_WriteRAM
    /* E2H Set PLL MN*/
    LCD_WR_REG(0x00E2);	
    /* 1 VCOƵ
       SSD1963ⲿƵΪ10MHzVCOҪ250MHz
       36Ƶ360MHz*/
    LCD_WR_DATA(0x0023);
    /* 2 PLLƵ
       M=2, PLL=360/(M+1)=120MHz*/     
    LCD_WR_DATA(0x0002);
    /* 3 ʹЧ*/       						 
    LCD_WR_DATA(0x0004);

    LCD_WR_REG(0x00E0);     /* Set PLL */
    LCD_WR_DATA(0x0001);   /* PLL enable  */
    Delay_10ms(10);        /* ʱ100ms   */
    LCD_WR_REG(0x00E0);	  
    LCD_WR_DATA(0x0003);
    Delay_10ms(10);


    LCD_WR_REG(0x0001);   /*  λûв */
    Delay_10ms(10);

    LCD_WR_REG(0x00E6);   /*  Set LSHIFT Frequency */
    LCD_WR_DATA(0x0004);
    LCD_WR_DATA(0x0093);
    LCD_WR_DATA(0x00e0);

    LCD_WR_REG(0x00B0);            /*Set LCD Mode */
    LCD_WR_DATA(0x0000);
    LCD_WR_DATA(0x0000);
    LCD_WR_DATA((HDP>>8)&0X00FF);  /*Set the horizontal panel size*/  
    LCD_WR_DATA(HDP&0X00FF);
    LCD_WR_DATA((VDP>>8)&0X00FF);  /*Set the horizontal panel size*/ 
    LCD_WR_DATA(VDP&0X00FF);
    LCD_WR_DATA(0x0000);

    LCD_WR_REG(0x00B4);            /*Set Horizontal Period */
    LCD_WR_DATA((HT>>8)&0X00FF);  //Set HT
    LCD_WR_DATA(HT&0X00FF);
    LCD_WR_DATA((HPS>>8)&0X00FF);  //Set HPS
    LCD_WR_DATA(HPS&0X00FF);
    LCD_WR_DATA(HPW);              //Set HPW
    LCD_WR_DATA((LPS>>8)&0X00FF);  //Set HPS
    LCD_WR_DATA(LPS&0X00FF);
    LCD_WR_DATA(0x0000);

    LCD_WR_REG(0x00B6);            //VSYNC
    LCD_WR_DATA((VT>>8)&0X00FF);   //Set VT
    LCD_WR_DATA(VT&0X00FF);
    LCD_WR_DATA((VPS>>8)&0X00FF);  //Set VPS
    LCD_WR_DATA(VPS&0X00FF);
    LCD_WR_DATA(VPW);              //Set VPW
    LCD_WR_DATA((FPS>>8)&0X00FF);  //Set FPS
    LCD_WR_DATA(FPS&0X00FF);

    LCD_WR_REG(0x00BA);
    LCD_WR_DATA(0x0005);           //GPIO[3:0] out 1

    LCD_WR_REG(0x00B8);
    LCD_WR_DATA(0x0007);    //GPIO3=input, GPIO[2:0]=output
    LCD_WR_DATA(0x0001);    //GPIO0 normal

    LCD_WR_REG(0x0036);       //rotation
    LCD_WR_DATA(0x0008);

    LCD_WR_REG(0x00F0);     //pixel data interface
    LCD_WR_DATA(0x0003);


    Delay_10ms(50);
    LCD_WR_REG(0x0029);        //display on

    LCD_WR_REG(0x00BE);        //set PWM for B/L
    LCD_WR_DATA(0x0006);
    LCD_WR_DATA(0x0080);
    
    LCD_WR_DATA(0x0001);
    LCD_WR_DATA(0x00f0);
    LCD_WR_DATA(0x0000);
    LCD_WR_DATA(0x0000);

    LCD_WR_REG(0x00d0);//ö̬ 
    LCD_WR_DATA(0x000d);
}
